# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class BatchCreateLlmTemplatesResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.BatchCreateLlmTemplatesResponseBodyData = None,
        request_id: str = None,
    ):
        self.data = data
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            temp_model = main_models.BatchCreateLlmTemplatesResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class BatchCreateLlmTemplatesResponseBodyData(DaraModel):
    def __init__(
        self,
        llm_template_ids: List[str] = None,
        skipped_items: List[main_models.BatchCreateLlmTemplatesResponseBodyDataSkippedItems] = None,
        success_count: int = None,
        total_count: int = None,
    ):
        self.llm_template_ids = llm_template_ids
        self.skipped_items = skipped_items
        self.success_count = success_count
        self.total_count = total_count

    def validate(self):
        if self.skipped_items:
            for v1 in self.skipped_items:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.llm_template_ids is not None:
            result['LlmTemplateIds'] = self.llm_template_ids

        result['SkippedItems'] = []
        if self.skipped_items is not None:
            for k1 in self.skipped_items:
                result['SkippedItems'].append(k1.to_map() if k1 else None)

        if self.success_count is not None:
            result['SuccessCount'] = self.success_count

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('LlmTemplateIds') is not None:
            self.llm_template_ids = m.get('LlmTemplateIds')

        self.skipped_items = []
        if m.get('SkippedItems') is not None:
            for k1 in m.get('SkippedItems'):
                temp_model = main_models.BatchCreateLlmTemplatesResponseBodyDataSkippedItems()
                self.skipped_items.append(temp_model.from_map(k1))

        if m.get('SuccessCount') is not None:
            self.success_count = m.get('SuccessCount')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class BatchCreateLlmTemplatesResponseBodyDataSkippedItems(DaraModel):
    def __init__(
        self,
        llm_code: str = None,
        reason: str = None,
    ):
        self.llm_code = llm_code
        self.reason = reason

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.llm_code is not None:
            result['LlmCode'] = self.llm_code

        if self.reason is not None:
            result['Reason'] = self.reason

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('LlmCode') is not None:
            self.llm_code = m.get('LlmCode')

        if m.get('Reason') is not None:
            self.reason = m.get('Reason')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListDesktopAgentRuntimeRequest(DaraModel):
    def __init__(
        self,
        agent_instance_statuses: List[str] = None,
        agent_instance_versions: List[str] = None,
        agent_platform: str = None,
        agent_provider: str = None,
        auth_users: List[str] = None,
        biz_type: int = None,
        channel_configure: bool = None,
        deployment_source: str = None,
        desktop_ids: List[str] = None,
        desktop_names: List[str] = None,
        desktop_statuses: List[str] = None,
        has_auth_user: bool = None,
        has_risk: bool = None,
        include_risk_info: bool = None,
        model_configure: bool = None,
        model_template_id: str = None,
        page_number: int = None,
        page_size: int = None,
        resource_group_id: str = None,
        resource_ids: List[str] = None,
    ):
        self.agent_instance_statuses = agent_instance_statuses
        self.agent_instance_versions = agent_instance_versions
        self.agent_platform = agent_platform
        # This parameter is required.
        self.agent_provider = agent_provider
        self.auth_users = auth_users
        self.biz_type = biz_type
        self.channel_configure = channel_configure
        self.deployment_source = deployment_source
        self.desktop_ids = desktop_ids
        self.desktop_names = desktop_names
        self.desktop_statuses = desktop_statuses
        self.has_auth_user = has_auth_user
        self.has_risk = has_risk
        self.include_risk_info = include_risk_info
        self.model_configure = model_configure
        self.model_template_id = model_template_id
        self.page_number = page_number
        self.page_size = page_size
        self.resource_group_id = resource_group_id
        self.resource_ids = resource_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_instance_statuses is not None:
            result['AgentInstanceStatuses'] = self.agent_instance_statuses

        if self.agent_instance_versions is not None:
            result['AgentInstanceVersions'] = self.agent_instance_versions

        if self.agent_platform is not None:
            result['AgentPlatform'] = self.agent_platform

        if self.agent_provider is not None:
            result['AgentProvider'] = self.agent_provider

        if self.auth_users is not None:
            result['AuthUsers'] = self.auth_users

        if self.biz_type is not None:
            result['BizType'] = self.biz_type

        if self.channel_configure is not None:
            result['ChannelConfigure'] = self.channel_configure

        if self.deployment_source is not None:
            result['DeploymentSource'] = self.deployment_source

        if self.desktop_ids is not None:
            result['DesktopIds'] = self.desktop_ids

        if self.desktop_names is not None:
            result['DesktopNames'] = self.desktop_names

        if self.desktop_statuses is not None:
            result['DesktopStatuses'] = self.desktop_statuses

        if self.has_auth_user is not None:
            result['HasAuthUser'] = self.has_auth_user

        if self.has_risk is not None:
            result['HasRisk'] = self.has_risk

        if self.include_risk_info is not None:
            result['IncludeRiskInfo'] = self.include_risk_info

        if self.model_configure is not None:
            result['ModelConfigure'] = self.model_configure

        if self.model_template_id is not None:
            result['ModelTemplateId'] = self.model_template_id

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.resource_ids is not None:
            result['ResourceIds'] = self.resource_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentInstanceStatuses') is not None:
            self.agent_instance_statuses = m.get('AgentInstanceStatuses')

        if m.get('AgentInstanceVersions') is not None:
            self.agent_instance_versions = m.get('AgentInstanceVersions')

        if m.get('AgentPlatform') is not None:
            self.agent_platform = m.get('AgentPlatform')

        if m.get('AgentProvider') is not None:
            self.agent_provider = m.get('AgentProvider')

        if m.get('AuthUsers') is not None:
            self.auth_users = m.get('AuthUsers')

        if m.get('BizType') is not None:
            self.biz_type = m.get('BizType')

        if m.get('ChannelConfigure') is not None:
            self.channel_configure = m.get('ChannelConfigure')

        if m.get('DeploymentSource') is not None:
            self.deployment_source = m.get('DeploymentSource')

        if m.get('DesktopIds') is not None:
            self.desktop_ids = m.get('DesktopIds')

        if m.get('DesktopNames') is not None:
            self.desktop_names = m.get('DesktopNames')

        if m.get('DesktopStatuses') is not None:
            self.desktop_statuses = m.get('DesktopStatuses')

        if m.get('HasAuthUser') is not None:
            self.has_auth_user = m.get('HasAuthUser')

        if m.get('HasRisk') is not None:
            self.has_risk = m.get('HasRisk')

        if m.get('IncludeRiskInfo') is not None:
            self.include_risk_info = m.get('IncludeRiskInfo')

        if m.get('ModelConfigure') is not None:
            self.model_configure = m.get('ModelConfigure')

        if m.get('ModelTemplateId') is not None:
            self.model_template_id = m.get('ModelTemplateId')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('ResourceIds') is not None:
            self.resource_ids = m.get('ResourceIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class TagCloudResourcesRequest(DaraModel):
    def __init__(
        self,
        resource_ids: List[str] = None,
        resource_type: str = None,
        tags: List[main_models.TagCloudResourcesRequestTags] = None,
    ):
        # The resource IDs. You can specify up to 50 resource IDs. You do not need to specify this parameter if you set ResourceType to AliUid.
        self.resource_ids = resource_ids
        # The type of the cloud resource.
        # 
        # Valid values:
        # 
        # *   CenterImageId: center image ID.
        # *   AppId: app ID.
        # *   WyId: Alibaba Cloud Workspace user ID.
        # *   AppInstanceGroupId: delivery group ID.
        # *   AliUid: tenant ID.
        # 
        # This parameter is required.
        self.resource_type = resource_type
        # The tags that you want to remove from the cloud resources. System and custom tags are supported.
        # 
        # *   Valid values for system tags:
        # 
        #     *   `System/Scheduler/GRAYSCALE`: canary tags.
        #     *   `System/Scheduler/STOP_NEW_USER_CONNECTION`: tags used to stop new users bound to the delivery group from establishing a connection.
        # 
        # *   You can create up to 20 custom tags.
        # 
        # > Each tag key on a resource can have only one tag value. If you create a tag that has the same key as an existing tag, the value of the existing tag is overwritten.
        # 
        # This parameter is required.
        self.tags = tags

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_ids is not None:
            result['ResourceIds'] = self.resource_ids

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ResourceIds') is not None:
            self.resource_ids = m.get('ResourceIds')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.TagCloudResourcesRequestTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class TagCloudResourcesRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The key of a tag. The value must be 1 to 128 characters in length and is case-sensitive. The name must be 1 to 128 characters in length.
        # 
        # This parameter is required.
        self.key = key
        # The value of a tag. The value must be 1 to 128 characters in length and is case-sensitive. The name must be 1 to 128 characters in length.
        # 
        # This parameter is required.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class CreateModelProviderTemplateResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.CreateModelProviderTemplateResponseBodyData = None,
        request_id: str = None,
    ):
        self.data = data
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            temp_model = main_models.CreateModelProviderTemplateResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class CreateModelProviderTemplateResponseBodyData(DaraModel):
    def __init__(
        self,
        provider_template_id: str = None,
    ):
        self.provider_template_id = provider_template_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.provider_template_id is not None:
            result['ProviderTemplateId'] = self.provider_template_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ProviderTemplateId') is not None:
            self.provider_template_id = m.get('ProviderTemplateId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class UpdateModelProviderTemplateRequest(DaraModel):
    def __init__(
        self,
        config: main_models.UpdateModelProviderTemplateRequestConfig = None,
        description: str = None,
        enable_wuying_proxy: bool = None,
        name: str = None,
        provider_template_id: str = None,
    ):
        self.config = config
        self.description = description
        self.enable_wuying_proxy = enable_wuying_proxy
        self.name = name
        # This parameter is required.
        self.provider_template_id = provider_template_id

    def validate(self):
        if self.config:
            self.config.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config is not None:
            result['Config'] = self.config.to_map()

        if self.description is not None:
            result['Description'] = self.description

        if self.enable_wuying_proxy is not None:
            result['EnableWuyingProxy'] = self.enable_wuying_proxy

        if self.name is not None:
            result['Name'] = self.name

        if self.provider_template_id is not None:
            result['ProviderTemplateId'] = self.provider_template_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Config') is not None:
            temp_model = main_models.UpdateModelProviderTemplateRequestConfig()
            self.config = temp_model.from_map(m.get('Config'))

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('EnableWuyingProxy') is not None:
            self.enable_wuying_proxy = m.get('EnableWuyingProxy')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('ProviderTemplateId') is not None:
            self.provider_template_id = m.get('ProviderTemplateId')

        return self

class UpdateModelProviderTemplateRequestConfig(DaraModel):
    def __init__(
        self,
        api_key: str = None,
        api_type: str = None,
        base_url: str = None,
    ):
        self.api_key = api_key
        self.api_type = api_type
        self.base_url = base_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.api_key is not None:
            result['ApiKey'] = self.api_key

        if self.api_type is not None:
            result['ApiType'] = self.api_type

        if self.base_url is not None:
            result['BaseUrl'] = self.base_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ApiKey') is not None:
            self.api_key = m.get('ApiKey')

        if m.get('ApiType') is not None:
            self.api_type = m.get('ApiType')

        if m.get('BaseUrl') is not None:
            self.base_url = m.get('BaseUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ConfigRuntimeChannelRequest(DaraModel):
    def __init__(
        self,
        agent_platform: str = None,
        agent_provider: str = None,
        code: str = None,
        config: str = None,
        config_mode: str = None,
        name: str = None,
        runtime_ids: List[str] = None,
        runtime_type: str = None,
    ):
        self.agent_platform = agent_platform
        # This parameter is required.
        self.agent_provider = agent_provider
        # This parameter is required.
        self.code = code
        # This parameter is required.
        self.config = config
        self.config_mode = config_mode
        self.name = name
        # This parameter is required.
        self.runtime_ids = runtime_ids
        # This parameter is required.
        self.runtime_type = runtime_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_platform is not None:
            result['AgentPlatform'] = self.agent_platform

        if self.agent_provider is not None:
            result['AgentProvider'] = self.agent_provider

        if self.code is not None:
            result['Code'] = self.code

        if self.config is not None:
            result['Config'] = self.config

        if self.config_mode is not None:
            result['ConfigMode'] = self.config_mode

        if self.name is not None:
            result['Name'] = self.name

        if self.runtime_ids is not None:
            result['RuntimeIds'] = self.runtime_ids

        if self.runtime_type is not None:
            result['RuntimeType'] = self.runtime_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentPlatform') is not None:
            self.agent_platform = m.get('AgentPlatform')

        if m.get('AgentProvider') is not None:
            self.agent_provider = m.get('AgentProvider')

        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Config') is not None:
            self.config = m.get('Config')

        if m.get('ConfigMode') is not None:
            self.config_mode = m.get('ConfigMode')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('RuntimeIds') is not None:
            self.runtime_ids = m.get('RuntimeIds')

        if m.get('RuntimeType') is not None:
            self.runtime_type = m.get('RuntimeType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ApproveOtaTaskRequest(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        biz_region_id: str = None,
        ota_type: str = None,
        start_time: str = None,
        task_id: str = None,
    ):
        # The ID of the delivery group. You can call the [ListAppInstanceGroup](https://help.aliyun.com/document_detail/428506.html) operation to obtain the ID.
        # 
        # This parameter is required.
        self.app_instance_group_id = app_instance_group_id
        # The ID of the region where the delivery group resides. You can call the [ListRegions](https://help.aliyun.com/document_detail/428500.html) operation to query the list of regions supported by App Streaming.
        # 
        # This parameter is required.
        self.biz_region_id = biz_region_id
        # The type of the OTA update task.
        # 
        # Valid values:
        # 
        # *   Fota: update of the system components of Alibaba Cloud Workspace
        # *   AppUpdate
        # *   ImageUpdate
        # 
        # This parameter is required.
        self.ota_type = ota_type
        # The start time of the OTA update task. The time follows the ISO 8601 standard.
        # 
        # This parameter is required.
        # 
        # Use the UTC time format: yyyy-MM-ddTHH:mmZ
        self.start_time = start_time
        # The ID of the OTA update task. You can call the [ListAppInstanceGroup](https://help.aliyun.com/document_detail/428506.html) operation to obtain the ID.
        # 
        # >  Each successful call to the `ApproveOtaTask` operation causes a value change of this parameter.`` Before you call this operation, call the `ListAppInstanceGroup` operation again to obtain the latest value of this parameter.``
        # 
        # This parameter is required.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.ota_type is not None:
            result['OtaType'] = self.ota_type

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('OtaType') is not None:
            self.ota_type = m.get('OtaType')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListNodeInstanceTypeRequest(DaraModel):
    def __init__(
        self,
        biz_region_id: str = None,
        cpu: float = None,
        gpu: float = None,
        gpu_memory: int = None,
        instance_type_for_modify: str = None,
        language: str = None,
        memory: int = None,
        node_instance_type: str = None,
        node_instance_type_family: str = None,
        order_by: str = None,
        order_type: str = None,
        os_type: str = None,
        page_number: int = None,
        page_size: int = None,
        product_type: str = None,
        sort_type: str = None,
    ):
        # The ID of the region where the resource resides. For information about the supported regions, see [Limits](https://help.aliyun.com/document_detail/426036.html).
        # 
        # Valid values:
        # 
        # *   cn-shanghai: China (Shanghai)
        # *   cn-hangzhou: China (Hangzhou)
        self.biz_region_id = biz_region_id
        self.cpu = cpu
        self.gpu = gpu
        self.gpu_memory = gpu_memory
        self.instance_type_for_modify = instance_type_for_modify
        # The language that you want to use.
        # 
        # Valid values:
        # 
        # *   en-US: English (US)
        # *   zh-CN: Simplified Chinese
        self.language = language
        self.memory = memory
        # The resource type that you want to query. If you do not configure this parameter, all resource types are returned.
        self.node_instance_type = node_instance_type
        self.node_instance_type_family = node_instance_type_family
        self.order_by = order_by
        self.order_type = order_type
        # The operating system that is supported.
        # 
        # Valid value:
        # 
        # *   Windows: the Windows operating system
        self.os_type = os_type
        # The number of the page to return.
        # 
        # This parameter is required.
        self.page_number = page_number
        # The number of entries to return on each page. Valid values: 1 to 100.
        # 
        # This parameter is required.
        self.page_size = page_size
        # The product type.
        # 
        # Valid value:
        # 
        # *   CloudApp: App Streaming
        # 
        # This parameter is required.
        self.product_type = product_type
        self.sort_type = sort_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.cpu is not None:
            result['Cpu'] = self.cpu

        if self.gpu is not None:
            result['Gpu'] = self.gpu

        if self.gpu_memory is not None:
            result['GpuMemory'] = self.gpu_memory

        if self.instance_type_for_modify is not None:
            result['InstanceTypeForModify'] = self.instance_type_for_modify

        if self.language is not None:
            result['Language'] = self.language

        if self.memory is not None:
            result['Memory'] = self.memory

        if self.node_instance_type is not None:
            result['NodeInstanceType'] = self.node_instance_type

        if self.node_instance_type_family is not None:
            result['NodeInstanceTypeFamily'] = self.node_instance_type_family

        if self.order_by is not None:
            result['OrderBy'] = self.order_by

        if self.order_type is not None:
            result['OrderType'] = self.order_type

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.sort_type is not None:
            result['SortType'] = self.sort_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('Cpu') is not None:
            self.cpu = m.get('Cpu')

        if m.get('Gpu') is not None:
            self.gpu = m.get('Gpu')

        if m.get('GpuMemory') is not None:
            self.gpu_memory = m.get('GpuMemory')

        if m.get('InstanceTypeForModify') is not None:
            self.instance_type_for_modify = m.get('InstanceTypeForModify')

        if m.get('Language') is not None:
            self.language = m.get('Language')

        if m.get('Memory') is not None:
            self.memory = m.get('Memory')

        if m.get('NodeInstanceType') is not None:
            self.node_instance_type = m.get('NodeInstanceType')

        if m.get('NodeInstanceTypeFamily') is not None:
            self.node_instance_type_family = m.get('NodeInstanceTypeFamily')

        if m.get('OrderBy') is not None:
            self.order_by = m.get('OrderBy')

        if m.get('OrderType') is not None:
            self.order_type = m.get('OrderType')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('SortType') is not None:
            self.sort_type = m.get('SortType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListImageResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        count: int = None,
        data: List[main_models.ListImageResponseBodyData] = None,
        message: str = None,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code that is returned.
        self.code = code
        # The total number of entries.
        self.count = count
        # The returned data.
        self.data = data
        # The message that is returned for the request.
        self.message = message
        # The page number returned.
        self.page_number = page_number
        # The number of entries per page.
        self.page_size = page_size
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful.
        # 
        # Valid values:
        # 
        # *   true: The request is successful.
        # *   false: The request failed.
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.count is not None:
            result['Count'] = self.count

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.message is not None:
            result['Message'] = self.message

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListImageResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class ListImageResponseBodyData(DaraModel):
    def __init__(
        self,
        ali_uid: int = None,
        app_list: List[main_models.ListImageResponseBodyDataAppList] = None,
        base_image_id: str = None,
        base_image_version: str = None,
        biz_type: int = None,
        compatible_mode: bool = None,
        data_disk_size: int = None,
        description: str = None,
        distro: str = None,
        driver_list: List[str] = None,
        environment_id: str = None,
        feature_list: List[str] = None,
        fota_channel: str = None,
        fota_version: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        image_create_mode: str = None,
        image_icon_url: str = None,
        image_id: str = None,
        image_name: str = None,
        image_region_distribute_list: List[main_models.ListImageResponseBodyDataImageRegionDistributeList] = None,
        image_region_list: List[str] = None,
        image_type: str = None,
        language: str = None,
        latest_version_id: str = None,
        online_version: bool = None,
        online_version_id: str = None,
        os_type: str = None,
        package_type: str = None,
        parent_image_id: str = None,
        parent_image_version: str = None,
        platform: int = None,
        platform_name: str = None,
        product_type: str = None,
        protocol_type: str = None,
        rating: int = None,
        resource_instance_category: str = None,
        scene: str = None,
        session_type: str = None,
        snapshot_list: List[main_models.ListImageResponseBodyDataSnapshotList] = None,
        status: str = None,
        supported_language_list: List[str] = None,
        system_disk_size: int = None,
        tag_list: List[main_models.ListImageResponseBodyDataTagList] = None,
        version_id: str = None,
        version_name: str = None,
        volume_encryption_enabled: bool = None,
        volume_encryption_key: str = None,
    ):
        # The tenant ID.
        self.ali_uid = ali_uid
        # The application configuration.
        self.app_list = app_list
        # The base image ID.
        self.base_image_id = base_image_id
        # The version of the base image.
        self.base_image_version = base_image_version
        # The service type.
        self.biz_type = biz_type
        # Specifies whether to use the compatibility mode.
        self.compatible_mode = compatible_mode
        # The size of the data disk. Unit: GiB.
        self.data_disk_size = data_disk_size
        # The description of the image.
        self.description = description
        # The name of the release.
        self.distro = distro
        # The information about each driver.
        self.driver_list = driver_list
        self.environment_id = environment_id
        # The image feature tags.
        self.feature_list = feature_list
        # >  This parameter is not available for public use.
        self.fota_channel = fota_channel
        # The FOTA version.
        self.fota_version = fota_version
        # The creation time.
        self.gmt_create = gmt_create
        # The update time.
        self.gmt_modified = gmt_modified
        # The image creation type.
        # 
        # Valid values:
        # 
        # *   BY_SNAPSHOT_ID: The image is created from the snapshot or contains only a system disk.
        # *   BUILDER_MANUAL: The image is manually generated.
        # *   INSTANCE_AUTO: The image is automatically generated based on an instance.
        # *   BY_INSTANCE_ID: The image is created from an instance or contains both a system disk and data disks.
        self.image_create_mode = image_create_mode
        self.image_icon_url = image_icon_url
        # System image IDs follow a descriptive, human-readable format, while custom image IDs are automatically generated by the system.
        self.image_id = image_id
        # The image name.
        self.image_name = image_name
        # Layered supported regions information.
        self.image_region_distribute_list = image_region_distribute_list
        # The region ID.
        self.image_region_list = image_region_list
        # The type of the image.
        self.image_type = image_type
        # The image language. When the packaging type is VHD or Container, the image inherits its properties from the ECS-type image within the same image bundle.
        self.language = language
        # The latest sub-version of the image. (An image consists of multiple sub-versions.)
        self.latest_version_id = latest_version_id
        # Indicates whether the current version is the active version.
        self.online_version = online_version
        # This image tag currently points to the specified sub-version of the parent image. (An image consists of multiple sub-versions.)
        self.online_version_id = online_version_id
        # The type of the image.
        self.os_type = os_type
        # The image encapsulation type.
        self.package_type = package_type
        # The ID of the parent image from which this image is derived. Note: This field is only applicable to custom images, as system images do not have a parent.
        self.parent_image_id = parent_image_id
        # The version of the parent image.
        self.parent_image_version = parent_image_version
        # The operating system platform of the image.
        # 
        # >  When the packaging type is VHD or Container, the image inherits its properties from the ECS-type image within the same image bundle.
        self.platform = platform
        # The name of the operating system platform.
        self.platform_name = platform_name
        # The product type.
        self.product_type = product_type
        # The protocol type.
        self.protocol_type = protocol_type
        self.rating = rating
        # The types of resources that are supported by the images.
        self.resource_instance_category = resource_instance_category
        self.scene = scene
        # The type of the session.
        # 
        # Valid values:
        # 
        # *   SINGLE_SESSION
        # *   MULTIPLE_SESSION
        self.session_type = session_type
        self.snapshot_list = snapshot_list
        # The state of the image.
        self.status = status
        # The supported languages.
        self.supported_language_list = supported_language_list
        # The size of the system disk. Unit: GiB.
        # 
        # >  The system disk must be at least as large as the image.
        self.system_disk_size = system_disk_size
        self.tag_list = tag_list
        # The version of the image.
        self.version_id = version_id
        # The version number.
        self.version_name = version_name
        # Specifies whether to enable disk encryption.
        self.volume_encryption_enabled = volume_encryption_enabled
        # The ID of the Key Management Service (KMS) key that is used to encrypt the disk.
        self.volume_encryption_key = volume_encryption_key

    def validate(self):
        if self.app_list:
            for v1 in self.app_list:
                 if v1:
                    v1.validate()
        if self.image_region_distribute_list:
            for v1 in self.image_region_distribute_list:
                 if v1:
                    v1.validate()
        if self.snapshot_list:
            for v1 in self.snapshot_list:
                 if v1:
                    v1.validate()
        if self.tag_list:
            for v1 in self.tag_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ali_uid is not None:
            result['AliUid'] = self.ali_uid

        result['AppList'] = []
        if self.app_list is not None:
            for k1 in self.app_list:
                result['AppList'].append(k1.to_map() if k1 else None)

        if self.base_image_id is not None:
            result['BaseImageId'] = self.base_image_id

        if self.base_image_version is not None:
            result['BaseImageVersion'] = self.base_image_version

        if self.biz_type is not None:
            result['BizType'] = self.biz_type

        if self.compatible_mode is not None:
            result['CompatibleMode'] = self.compatible_mode

        if self.data_disk_size is not None:
            result['DataDiskSize'] = self.data_disk_size

        if self.description is not None:
            result['Description'] = self.description

        if self.distro is not None:
            result['Distro'] = self.distro

        if self.driver_list is not None:
            result['DriverList'] = self.driver_list

        if self.environment_id is not None:
            result['EnvironmentId'] = self.environment_id

        if self.feature_list is not None:
            result['FeatureList'] = self.feature_list

        if self.fota_channel is not None:
            result['FotaChannel'] = self.fota_channel

        if self.fota_version is not None:
            result['FotaVersion'] = self.fota_version

        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['GmtModified'] = self.gmt_modified

        if self.image_create_mode is not None:
            result['ImageCreateMode'] = self.image_create_mode

        if self.image_icon_url is not None:
            result['ImageIconUrl'] = self.image_icon_url

        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.image_name is not None:
            result['ImageName'] = self.image_name

        result['ImageRegionDistributeList'] = []
        if self.image_region_distribute_list is not None:
            for k1 in self.image_region_distribute_list:
                result['ImageRegionDistributeList'].append(k1.to_map() if k1 else None)

        if self.image_region_list is not None:
            result['ImageRegionList'] = self.image_region_list

        if self.image_type is not None:
            result['ImageType'] = self.image_type

        if self.language is not None:
            result['Language'] = self.language

        if self.latest_version_id is not None:
            result['LatestVersionId'] = self.latest_version_id

        if self.online_version is not None:
            result['OnlineVersion'] = self.online_version

        if self.online_version_id is not None:
            result['OnlineVersionId'] = self.online_version_id

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.package_type is not None:
            result['PackageType'] = self.package_type

        if self.parent_image_id is not None:
            result['ParentImageId'] = self.parent_image_id

        if self.parent_image_version is not None:
            result['ParentImageVersion'] = self.parent_image_version

        if self.platform is not None:
            result['Platform'] = self.platform

        if self.platform_name is not None:
            result['PlatformName'] = self.platform_name

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.protocol_type is not None:
            result['ProtocolType'] = self.protocol_type

        if self.rating is not None:
            result['Rating'] = self.rating

        if self.resource_instance_category is not None:
            result['ResourceInstanceCategory'] = self.resource_instance_category

        if self.scene is not None:
            result['Scene'] = self.scene

        if self.session_type is not None:
            result['SessionType'] = self.session_type

        result['SnapshotList'] = []
        if self.snapshot_list is not None:
            for k1 in self.snapshot_list:
                result['SnapshotList'].append(k1.to_map() if k1 else None)

        if self.status is not None:
            result['Status'] = self.status

        if self.supported_language_list is not None:
            result['SupportedLanguageList'] = self.supported_language_list

        if self.system_disk_size is not None:
            result['SystemDiskSize'] = self.system_disk_size

        result['TagList'] = []
        if self.tag_list is not None:
            for k1 in self.tag_list:
                result['TagList'].append(k1.to_map() if k1 else None)

        if self.version_id is not None:
            result['VersionId'] = self.version_id

        if self.version_name is not None:
            result['VersionName'] = self.version_name

        if self.volume_encryption_enabled is not None:
            result['VolumeEncryptionEnabled'] = self.volume_encryption_enabled

        if self.volume_encryption_key is not None:
            result['VolumeEncryptionKey'] = self.volume_encryption_key

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AliUid') is not None:
            self.ali_uid = m.get('AliUid')

        self.app_list = []
        if m.get('AppList') is not None:
            for k1 in m.get('AppList'):
                temp_model = main_models.ListImageResponseBodyDataAppList()
                self.app_list.append(temp_model.from_map(k1))

        if m.get('BaseImageId') is not None:
            self.base_image_id = m.get('BaseImageId')

        if m.get('BaseImageVersion') is not None:
            self.base_image_version = m.get('BaseImageVersion')

        if m.get('BizType') is not None:
            self.biz_type = m.get('BizType')

        if m.get('CompatibleMode') is not None:
            self.compatible_mode = m.get('CompatibleMode')

        if m.get('DataDiskSize') is not None:
            self.data_disk_size = m.get('DataDiskSize')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('Distro') is not None:
            self.distro = m.get('Distro')

        if m.get('DriverList') is not None:
            self.driver_list = m.get('DriverList')

        if m.get('EnvironmentId') is not None:
            self.environment_id = m.get('EnvironmentId')

        if m.get('FeatureList') is not None:
            self.feature_list = m.get('FeatureList')

        if m.get('FotaChannel') is not None:
            self.fota_channel = m.get('FotaChannel')

        if m.get('FotaVersion') is not None:
            self.fota_version = m.get('FotaVersion')

        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')

        if m.get('GmtModified') is not None:
            self.gmt_modified = m.get('GmtModified')

        if m.get('ImageCreateMode') is not None:
            self.image_create_mode = m.get('ImageCreateMode')

        if m.get('ImageIconUrl') is not None:
            self.image_icon_url = m.get('ImageIconUrl')

        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('ImageName') is not None:
            self.image_name = m.get('ImageName')

        self.image_region_distribute_list = []
        if m.get('ImageRegionDistributeList') is not None:
            for k1 in m.get('ImageRegionDistributeList'):
                temp_model = main_models.ListImageResponseBodyDataImageRegionDistributeList()
                self.image_region_distribute_list.append(temp_model.from_map(k1))

        if m.get('ImageRegionList') is not None:
            self.image_region_list = m.get('ImageRegionList')

        if m.get('ImageType') is not None:
            self.image_type = m.get('ImageType')

        if m.get('Language') is not None:
            self.language = m.get('Language')

        if m.get('LatestVersionId') is not None:
            self.latest_version_id = m.get('LatestVersionId')

        if m.get('OnlineVersion') is not None:
            self.online_version = m.get('OnlineVersion')

        if m.get('OnlineVersionId') is not None:
            self.online_version_id = m.get('OnlineVersionId')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('PackageType') is not None:
            self.package_type = m.get('PackageType')

        if m.get('ParentImageId') is not None:
            self.parent_image_id = m.get('ParentImageId')

        if m.get('ParentImageVersion') is not None:
            self.parent_image_version = m.get('ParentImageVersion')

        if m.get('Platform') is not None:
            self.platform = m.get('Platform')

        if m.get('PlatformName') is not None:
            self.platform_name = m.get('PlatformName')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('ProtocolType') is not None:
            self.protocol_type = m.get('ProtocolType')

        if m.get('Rating') is not None:
            self.rating = m.get('Rating')

        if m.get('ResourceInstanceCategory') is not None:
            self.resource_instance_category = m.get('ResourceInstanceCategory')

        if m.get('Scene') is not None:
            self.scene = m.get('Scene')

        if m.get('SessionType') is not None:
            self.session_type = m.get('SessionType')

        self.snapshot_list = []
        if m.get('SnapshotList') is not None:
            for k1 in m.get('SnapshotList'):
                temp_model = main_models.ListImageResponseBodyDataSnapshotList()
                self.snapshot_list.append(temp_model.from_map(k1))

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('SupportedLanguageList') is not None:
            self.supported_language_list = m.get('SupportedLanguageList')

        if m.get('SystemDiskSize') is not None:
            self.system_disk_size = m.get('SystemDiskSize')

        self.tag_list = []
        if m.get('TagList') is not None:
            for k1 in m.get('TagList'):
                temp_model = main_models.ListImageResponseBodyDataTagList()
                self.tag_list.append(temp_model.from_map(k1))

        if m.get('VersionId') is not None:
            self.version_id = m.get('VersionId')

        if m.get('VersionName') is not None:
            self.version_name = m.get('VersionName')

        if m.get('VolumeEncryptionEnabled') is not None:
            self.volume_encryption_enabled = m.get('VolumeEncryptionEnabled')

        if m.get('VolumeEncryptionKey') is not None:
            self.volume_encryption_key = m.get('VolumeEncryptionKey')

        return self

class ListImageResponseBodyDataTagList(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self

class ListImageResponseBodyDataSnapshotList(DaraModel):
    def __init__(
        self,
        bind_type: str = None,
        disk_category: str = None,
        disk_sub_type: str = None,
        disk_type: str = None,
        size: int = None,
        snapshot_id: str = None,
        version_id: str = None,
    ):
        self.bind_type = bind_type
        self.disk_category = disk_category
        self.disk_sub_type = disk_sub_type
        self.disk_type = disk_type
        self.size = size
        self.snapshot_id = snapshot_id
        self.version_id = version_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bind_type is not None:
            result['BindType'] = self.bind_type

        if self.disk_category is not None:
            result['DiskCategory'] = self.disk_category

        if self.disk_sub_type is not None:
            result['DiskSubType'] = self.disk_sub_type

        if self.disk_type is not None:
            result['DiskType'] = self.disk_type

        if self.size is not None:
            result['Size'] = self.size

        if self.snapshot_id is not None:
            result['SnapshotId'] = self.snapshot_id

        if self.version_id is not None:
            result['VersionId'] = self.version_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BindType') is not None:
            self.bind_type = m.get('BindType')

        if m.get('DiskCategory') is not None:
            self.disk_category = m.get('DiskCategory')

        if m.get('DiskSubType') is not None:
            self.disk_sub_type = m.get('DiskSubType')

        if m.get('DiskType') is not None:
            self.disk_type = m.get('DiskType')

        if m.get('Size') is not None:
            self.size = m.get('Size')

        if m.get('SnapshotId') is not None:
            self.snapshot_id = m.get('SnapshotId')

        if m.get('VersionId') is not None:
            self.version_id = m.get('VersionId')

        return self

class ListImageResponseBodyDataImageRegionDistributeList(DaraModel):
    def __init__(
        self,
        image_id: str = None,
        progress: str = None,
        region_id: str = None,
        status: str = None,
        version_id: str = None,
    ):
        # System image IDs follow a descriptive, human-readable format, while custom image IDs are automatically generated by the system.
        self.image_id = image_id
        # The progress.
        self.progress = progress
        # The supported region.
        self.region_id = region_id
        # The status.
        self.status = status
        # The version of the image.
        self.version_id = version_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.progress is not None:
            result['Progress'] = self.progress

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.status is not None:
            result['Status'] = self.status

        if self.version_id is not None:
            result['VersionId'] = self.version_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('Progress') is not None:
            self.progress = m.get('Progress')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('VersionId') is not None:
            self.version_id = m.get('VersionId')

        return self

class ListImageResponseBodyDataAppList(DaraModel):
    def __init__(
        self,
        app_id: str = None,
        app_name: str = None,
    ):
        # The ID of the application.
        self.app_id = app_id
        # The name of the application.
        self.app_name = app_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_id is not None:
            result['AppId'] = self.app_id

        if self.app_name is not None:
            result['AppName'] = self.app_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppId') is not None:
            self.app_id = m.get('AppId')

        if m.get('AppName') is not None:
            self.app_name = m.get('AppName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListWuyingServerResponseBody(DaraModel):
    def __init__(
        self,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        total_count: int = None,
        wuying_server_list: List[main_models.ListWuyingServerResponseBodyWuyingServerList] = None,
    ):
        # The page number.
        self.page_number = page_number
        # The number of entries per page.
        self.page_size = page_size
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count
        # The list of workstation information.
        self.wuying_server_list = wuying_server_list

    def validate(self):
        if self.wuying_server_list:
            for v1 in self.wuying_server_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        result['WuyingServerList'] = []
        if self.wuying_server_list is not None:
            for k1 in self.wuying_server_list:
                result['WuyingServerList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        self.wuying_server_list = []
        if m.get('WuyingServerList') is not None:
            for k1 in m.get('WuyingServerList'):
                temp_model = main_models.ListWuyingServerResponseBodyWuyingServerList()
                self.wuying_server_list.append(temp_model.from_map(k1))

        return self

class ListWuyingServerResponseBodyWuyingServerList(DaraModel):
    def __init__(
        self,
        add_virtual_node_pool_status: str = None,
        ali_uid: int = None,
        bandwidth: int = None,
        biz_region_id: str = None,
        charge_type: str = None,
        create_time: str = None,
        data_disk: List[main_models.ListWuyingServerResponseBodyWuyingServerListDataDisk] = None,
        expired_time: str = None,
        fota_version: str = None,
        image_id: str = None,
        image_name: str = None,
        instance_info_list: List[main_models.ListWuyingServerResponseBodyWuyingServerListInstanceInfoList] = None,
        max_price: float = None,
        network_interface_ip: str = None,
        office_site_id: str = None,
        office_site_name: str = None,
        office_site_type: str = None,
        os_type: str = None,
        policy_group_id_list: List[str] = None,
        resource_session_status: str = None,
        security_group_ids: List[str] = None,
        server_instance_type_info: main_models.ListWuyingServerResponseBodyWuyingServerListServerInstanceTypeInfo = None,
        sessions: List[main_models.ListWuyingServerResponseBodyWuyingServerListSessions] = None,
        status: str = None,
        sub_pay_type: str = None,
        system_disk_category: str = None,
        system_disk_id: str = None,
        system_disk_performance_level: str = None,
        system_disk_size: int = None,
        timer_group_id: str = None,
        users: List[str] = None,
        virtual_kubelet_ip: str = None,
        virtual_node_pool_id: str = None,
        wuying_server_id: str = None,
        wuying_server_name: str = None,
    ):
        self.add_virtual_node_pool_status = add_virtual_node_pool_status
        self.ali_uid = ali_uid
        self.bandwidth = bandwidth
        # Region.
        self.biz_region_id = biz_region_id
        # The billing method.
        self.charge_type = charge_type
        # The time when the storage resource was created.
        self.create_time = create_time
        # The data disks.
        self.data_disk = data_disk
        # The time when the subscription instance expires.
        self.expired_time = expired_time
        self.fota_version = fota_version
        # The ID of the custom image.
        self.image_id = image_id
        # The image name.
        self.image_name = image_name
        # The list of information about the workstation instance.
        self.instance_info_list = instance_info_list
        self.max_price = max_price
        # The private IP address.
        self.network_interface_ip = network_interface_ip
        # The ID of the office network.
        self.office_site_id = office_site_id
        # The office network name.
        self.office_site_name = office_site_name
        # The type of the office network.
        self.office_site_type = office_site_type
        # The OS type.
        self.os_type = os_type
        self.policy_group_id_list = policy_group_id_list
        self.resource_session_status = resource_session_status
        self.security_group_ids = security_group_ids
        # The specifications.
        self.server_instance_type_info = server_instance_type_info
        self.sessions = sessions
        # The status of the workstation.
        self.status = status
        self.sub_pay_type = sub_pay_type
        # The type of the system disk.
        self.system_disk_category = system_disk_category
        self.system_disk_id = system_disk_id
        # The performance level (PL) of the system disk.
        self.system_disk_performance_level = system_disk_performance_level
        # The size of the system disk. Unit: GiB.
        self.system_disk_size = system_disk_size
        self.timer_group_id = timer_group_id
        self.users = users
        self.virtual_kubelet_ip = virtual_kubelet_ip
        self.virtual_node_pool_id = virtual_node_pool_id
        # The ID of the workstation.
        self.wuying_server_id = wuying_server_id
        # The name of the workstation.
        self.wuying_server_name = wuying_server_name

    def validate(self):
        if self.data_disk:
            for v1 in self.data_disk:
                 if v1:
                    v1.validate()
        if self.instance_info_list:
            for v1 in self.instance_info_list:
                 if v1:
                    v1.validate()
        if self.server_instance_type_info:
            self.server_instance_type_info.validate()
        if self.sessions:
            for v1 in self.sessions:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.add_virtual_node_pool_status is not None:
            result['AddVirtualNodePoolStatus'] = self.add_virtual_node_pool_status

        if self.ali_uid is not None:
            result['AliUid'] = self.ali_uid

        if self.bandwidth is not None:
            result['Bandwidth'] = self.bandwidth

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.charge_type is not None:
            result['ChargeType'] = self.charge_type

        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        result['DataDisk'] = []
        if self.data_disk is not None:
            for k1 in self.data_disk:
                result['DataDisk'].append(k1.to_map() if k1 else None)

        if self.expired_time is not None:
            result['ExpiredTime'] = self.expired_time

        if self.fota_version is not None:
            result['FotaVersion'] = self.fota_version

        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.image_name is not None:
            result['ImageName'] = self.image_name

        result['InstanceInfoList'] = []
        if self.instance_info_list is not None:
            for k1 in self.instance_info_list:
                result['InstanceInfoList'].append(k1.to_map() if k1 else None)

        if self.max_price is not None:
            result['MaxPrice'] = self.max_price

        if self.network_interface_ip is not None:
            result['NetworkInterfaceIp'] = self.network_interface_ip

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.office_site_name is not None:
            result['OfficeSiteName'] = self.office_site_name

        if self.office_site_type is not None:
            result['OfficeSiteType'] = self.office_site_type

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.policy_group_id_list is not None:
            result['PolicyGroupIdList'] = self.policy_group_id_list

        if self.resource_session_status is not None:
            result['ResourceSessionStatus'] = self.resource_session_status

        if self.security_group_ids is not None:
            result['SecurityGroupIds'] = self.security_group_ids

        if self.server_instance_type_info is not None:
            result['ServerInstanceTypeInfo'] = self.server_instance_type_info.to_map()

        result['Sessions'] = []
        if self.sessions is not None:
            for k1 in self.sessions:
                result['Sessions'].append(k1.to_map() if k1 else None)

        if self.status is not None:
            result['Status'] = self.status

        if self.sub_pay_type is not None:
            result['SubPayType'] = self.sub_pay_type

        if self.system_disk_category is not None:
            result['SystemDiskCategory'] = self.system_disk_category

        if self.system_disk_id is not None:
            result['SystemDiskId'] = self.system_disk_id

        if self.system_disk_performance_level is not None:
            result['SystemDiskPerformanceLevel'] = self.system_disk_performance_level

        if self.system_disk_size is not None:
            result['SystemDiskSize'] = self.system_disk_size

        if self.timer_group_id is not None:
            result['TimerGroupId'] = self.timer_group_id

        if self.users is not None:
            result['Users'] = self.users

        if self.virtual_kubelet_ip is not None:
            result['VirtualKubeletIp'] = self.virtual_kubelet_ip

        if self.virtual_node_pool_id is not None:
            result['VirtualNodePoolId'] = self.virtual_node_pool_id

        if self.wuying_server_id is not None:
            result['WuyingServerId'] = self.wuying_server_id

        if self.wuying_server_name is not None:
            result['WuyingServerName'] = self.wuying_server_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AddVirtualNodePoolStatus') is not None:
            self.add_virtual_node_pool_status = m.get('AddVirtualNodePoolStatus')

        if m.get('AliUid') is not None:
            self.ali_uid = m.get('AliUid')

        if m.get('Bandwidth') is not None:
            self.bandwidth = m.get('Bandwidth')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('ChargeType') is not None:
            self.charge_type = m.get('ChargeType')

        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        self.data_disk = []
        if m.get('DataDisk') is not None:
            for k1 in m.get('DataDisk'):
                temp_model = main_models.ListWuyingServerResponseBodyWuyingServerListDataDisk()
                self.data_disk.append(temp_model.from_map(k1))

        if m.get('ExpiredTime') is not None:
            self.expired_time = m.get('ExpiredTime')

        if m.get('FotaVersion') is not None:
            self.fota_version = m.get('FotaVersion')

        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('ImageName') is not None:
            self.image_name = m.get('ImageName')

        self.instance_info_list = []
        if m.get('InstanceInfoList') is not None:
            for k1 in m.get('InstanceInfoList'):
                temp_model = main_models.ListWuyingServerResponseBodyWuyingServerListInstanceInfoList()
                self.instance_info_list.append(temp_model.from_map(k1))

        if m.get('MaxPrice') is not None:
            self.max_price = m.get('MaxPrice')

        if m.get('NetworkInterfaceIp') is not None:
            self.network_interface_ip = m.get('NetworkInterfaceIp')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('OfficeSiteName') is not None:
            self.office_site_name = m.get('OfficeSiteName')

        if m.get('OfficeSiteType') is not None:
            self.office_site_type = m.get('OfficeSiteType')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('PolicyGroupIdList') is not None:
            self.policy_group_id_list = m.get('PolicyGroupIdList')

        if m.get('ResourceSessionStatus') is not None:
            self.resource_session_status = m.get('ResourceSessionStatus')

        if m.get('SecurityGroupIds') is not None:
            self.security_group_ids = m.get('SecurityGroupIds')

        if m.get('ServerInstanceTypeInfo') is not None:
            temp_model = main_models.ListWuyingServerResponseBodyWuyingServerListServerInstanceTypeInfo()
            self.server_instance_type_info = temp_model.from_map(m.get('ServerInstanceTypeInfo'))

        self.sessions = []
        if m.get('Sessions') is not None:
            for k1 in m.get('Sessions'):
                temp_model = main_models.ListWuyingServerResponseBodyWuyingServerListSessions()
                self.sessions.append(temp_model.from_map(k1))

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('SubPayType') is not None:
            self.sub_pay_type = m.get('SubPayType')

        if m.get('SystemDiskCategory') is not None:
            self.system_disk_category = m.get('SystemDiskCategory')

        if m.get('SystemDiskId') is not None:
            self.system_disk_id = m.get('SystemDiskId')

        if m.get('SystemDiskPerformanceLevel') is not None:
            self.system_disk_performance_level = m.get('SystemDiskPerformanceLevel')

        if m.get('SystemDiskSize') is not None:
            self.system_disk_size = m.get('SystemDiskSize')

        if m.get('TimerGroupId') is not None:
            self.timer_group_id = m.get('TimerGroupId')

        if m.get('Users') is not None:
            self.users = m.get('Users')

        if m.get('VirtualKubeletIp') is not None:
            self.virtual_kubelet_ip = m.get('VirtualKubeletIp')

        if m.get('VirtualNodePoolId') is not None:
            self.virtual_node_pool_id = m.get('VirtualNodePoolId')

        if m.get('WuyingServerId') is not None:
            self.wuying_server_id = m.get('WuyingServerId')

        if m.get('WuyingServerName') is not None:
            self.wuying_server_name = m.get('WuyingServerName')

        return self

class ListWuyingServerResponseBodyWuyingServerListSessions(DaraModel):
    def __init__(
        self,
        resource_session_start_time: str = None,
        user_id: str = None,
    ):
        self.resource_session_start_time = resource_session_start_time
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_session_start_time is not None:
            result['ResourceSessionStartTime'] = self.resource_session_start_time

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ResourceSessionStartTime') is not None:
            self.resource_session_start_time = m.get('ResourceSessionStartTime')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self

class ListWuyingServerResponseBodyWuyingServerListServerInstanceTypeInfo(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        gpu: str = None,
        gpu_memory: int = None,
        gpu_spec: str = None,
        memory: int = None,
        server_instance_type: str = None,
    ):
        # The number of vCPUs.
        self.cpu = cpu
        # The number of GPUs.
        self.gpu = gpu
        # The memory size. Unit: MB.
        self.gpu_memory = gpu_memory
        self.gpu_spec = gpu_spec
        # The memory size. Unit: MB.
        self.memory = memory
        # Workstation specifications.
        self.server_instance_type = server_instance_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['Cpu'] = self.cpu

        if self.gpu is not None:
            result['Gpu'] = self.gpu

        if self.gpu_memory is not None:
            result['GpuMemory'] = self.gpu_memory

        if self.gpu_spec is not None:
            result['GpuSpec'] = self.gpu_spec

        if self.memory is not None:
            result['Memory'] = self.memory

        if self.server_instance_type is not None:
            result['ServerInstanceType'] = self.server_instance_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Cpu') is not None:
            self.cpu = m.get('Cpu')

        if m.get('Gpu') is not None:
            self.gpu = m.get('Gpu')

        if m.get('GpuMemory') is not None:
            self.gpu_memory = m.get('GpuMemory')

        if m.get('GpuSpec') is not None:
            self.gpu_spec = m.get('GpuSpec')

        if m.get('Memory') is not None:
            self.memory = m.get('Memory')

        if m.get('ServerInstanceType') is not None:
            self.server_instance_type = m.get('ServerInstanceType')

        return self

class ListWuyingServerResponseBodyWuyingServerListInstanceInfoList(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        network_interface_id: str = None,
    ):
        # The ID of the instance.
        self.instance_id = instance_id
        # The ID of the ENI.
        self.network_interface_id = network_interface_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.network_interface_id is not None:
            result['NetworkInterfaceId'] = self.network_interface_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NetworkInterfaceId') is not None:
            self.network_interface_id = m.get('NetworkInterfaceId')

        return self

class ListWuyingServerResponseBodyWuyingServerListDataDisk(DaraModel):
    def __init__(
        self,
        data_disk_category: str = None,
        data_disk_id: str = None,
        data_disk_no: str = None,
        data_disk_performance_level: str = None,
        data_disk_size: int = None,
    ):
        # The category of data disk.
        self.data_disk_category = data_disk_category
        self.data_disk_id = data_disk_id
        self.data_disk_no = data_disk_no
        # The PL of the data disk.
        self.data_disk_performance_level = data_disk_performance_level
        # The size of the data disk. Unit: GB.
        self.data_disk_size = data_disk_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data_disk_category is not None:
            result['DataDiskCategory'] = self.data_disk_category

        if self.data_disk_id is not None:
            result['DataDiskId'] = self.data_disk_id

        if self.data_disk_no is not None:
            result['DataDiskNo'] = self.data_disk_no

        if self.data_disk_performance_level is not None:
            result['DataDiskPerformanceLevel'] = self.data_disk_performance_level

        if self.data_disk_size is not None:
            result['DataDiskSize'] = self.data_disk_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataDiskCategory') is not None:
            self.data_disk_category = m.get('DataDiskCategory')

        if m.get('DataDiskId') is not None:
            self.data_disk_id = m.get('DataDiskId')

        if m.get('DataDiskNo') is not None:
            self.data_disk_no = m.get('DataDiskNo')

        if m.get('DataDiskPerformanceLevel') is not None:
            self.data_disk_performance_level = m.get('DataDiskPerformanceLevel')

        if m.get('DataDiskSize') is not None:
            self.data_disk_size = m.get('DataDiskSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListTagCloudResourcesRequest(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        next_token: str = None,
        resource_ids: List[str] = None,
        resource_type: str = None,
        scope: str = None,
    ):
        # The number of entries per page. Maximum value: 1000. Default value: 50.
        self.max_results = max_results
        # The pagination token that is used in the next request to retrieve a new page of results.
        self.next_token = next_token
        # The resource IDs. You can specify up to 50 resource IDs. You do not need to specify this parameter if you set ResourceType to AliUid.
        self.resource_ids = resource_ids
        # The type of the cloud resource.
        # 
        # Valid values:
        # 
        # *   AppId: app ID.
        # *   WyId: Alibaba Cloud Workspace user ID.
        # *   AppInstanceGroupId: delivery group ID.
        # *   AliUid: tenant ID.
        # 
        # This parameter is required.
        self.resource_type = resource_type
        # The tag type.
        # 
        # Valid values:
        # 
        # *   All (default): all tags.
        # *   Custom: custom tag.
        # *   System: system tag.
        self.scope = scope

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['MaxResults'] = self.max_results

        if self.next_token is not None:
            result['NextToken'] = self.next_token

        if self.resource_ids is not None:
            result['ResourceIds'] = self.resource_ids

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        if self.scope is not None:
            result['Scope'] = self.scope

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('MaxResults') is not None:
            self.max_results = m.get('MaxResults')

        if m.get('NextToken') is not None:
            self.next_token = m.get('NextToken')

        if m.get('ResourceIds') is not None:
            self.resource_ids = m.get('ResourceIds')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        if m.get('Scope') is not None:
            self.scope = m.get('Scope')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class StartTaskForDistributeImageResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: str = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The error code if an error occurred.
        self.code = code
        # The ID of the image replication task.
        self.data = data
        # The error message if an error occurred.
        self.message = message
        # The ID of the request.
        self.request_id = request_id
        # Indicates whether the task is successful.
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            self.data = m.get('Data')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModifyNodePoolAttributeShrinkRequest(DaraModel):
    def __init__(
        self,
        biz_region_id: str = None,
        node_capacity: int = None,
        node_pool_strategy_shrink: str = None,
        pool_id: str = None,
        product_type: str = None,
    ):
        # The ID of the region where the delivery group resides. For information about the supported regions, see [Limits](https://help.aliyun.com/document_detail/426036.html).
        # 
        # Valid values:
        # 
        # *   cn-shanghai: China (Shanghai)
        # *   cn-hangzhou: China (Hangzhou)
        self.biz_region_id = biz_region_id
        self.node_capacity = node_capacity
        # The auto scaling policy used by the delivery group.
        self.node_pool_strategy_shrink = node_pool_strategy_shrink
        self.pool_id = pool_id
        # The product type.
        # 
        # Valid value:
        # 
        # *   CloudApp: App Streaming
        self.product_type = product_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.node_capacity is not None:
            result['NodeCapacity'] = self.node_capacity

        if self.node_pool_strategy_shrink is not None:
            result['NodePoolStrategy'] = self.node_pool_strategy_shrink

        if self.pool_id is not None:
            result['PoolId'] = self.pool_id

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('NodeCapacity') is not None:
            self.node_capacity = m.get('NodeCapacity')

        if m.get('NodePoolStrategy') is not None:
            self.node_pool_strategy_shrink = m.get('NodePoolStrategy')

        if m.get('PoolId') is not None:
            self.pool_id = m.get('PoolId')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListDesktopAgentRuntimeResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.ListDesktopAgentRuntimeResponseBodyData] = None,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        total_count: int = None,
    ):
        self.data = data
        self.page_number = page_number
        self.page_size = page_size
        self.request_id = request_id
        self.total_count = total_count

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListDesktopAgentRuntimeResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListDesktopAgentRuntimeResponseBodyData(DaraModel):
    def __init__(
        self,
        agent_im_info: main_models.ListDesktopAgentRuntimeResponseBodyDataAgentImInfo = None,
        agent_instance_info_list: List[main_models.ListDesktopAgentRuntimeResponseBodyDataAgentInstanceInfoList] = None,
        auth_users: List[str] = None,
        channel_configure: bool = None,
        channel_configured_list: List[str] = None,
        desktop_id: str = None,
        desktop_name: str = None,
        desktop_status: str = None,
        has_auth_user: bool = None,
        model_configure: bool = None,
        os_type: str = None,
        qr_code_configuring_list: List[str] = None,
        region_id: str = None,
        resource_group: main_models.ListDesktopAgentRuntimeResponseBodyDataResourceGroup = None,
        resource_id: str = None,
        risk_info: main_models.ListDesktopAgentRuntimeResponseBodyDataRiskInfo = None,
    ):
        self.agent_im_info = agent_im_info
        self.agent_instance_info_list = agent_instance_info_list
        self.auth_users = auth_users
        self.channel_configure = channel_configure
        self.channel_configured_list = channel_configured_list
        self.desktop_id = desktop_id
        self.desktop_name = desktop_name
        self.desktop_status = desktop_status
        self.has_auth_user = has_auth_user
        self.model_configure = model_configure
        self.os_type = os_type
        self.qr_code_configuring_list = qr_code_configuring_list
        self.region_id = region_id
        self.resource_group = resource_group
        self.resource_id = resource_id
        self.risk_info = risk_info

    def validate(self):
        if self.agent_im_info:
            self.agent_im_info.validate()
        if self.agent_instance_info_list:
            for v1 in self.agent_instance_info_list:
                 if v1:
                    v1.validate()
        if self.resource_group:
            self.resource_group.validate()
        if self.risk_info:
            self.risk_info.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_im_info is not None:
            result['AgentImInfo'] = self.agent_im_info.to_map()

        result['AgentInstanceInfoList'] = []
        if self.agent_instance_info_list is not None:
            for k1 in self.agent_instance_info_list:
                result['AgentInstanceInfoList'].append(k1.to_map() if k1 else None)

        if self.auth_users is not None:
            result['AuthUsers'] = self.auth_users

        if self.channel_configure is not None:
            result['ChannelConfigure'] = self.channel_configure

        if self.channel_configured_list is not None:
            result['ChannelConfiguredList'] = self.channel_configured_list

        if self.desktop_id is not None:
            result['DesktopId'] = self.desktop_id

        if self.desktop_name is not None:
            result['DesktopName'] = self.desktop_name

        if self.desktop_status is not None:
            result['DesktopStatus'] = self.desktop_status

        if self.has_auth_user is not None:
            result['HasAuthUser'] = self.has_auth_user

        if self.model_configure is not None:
            result['ModelConfigure'] = self.model_configure

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.qr_code_configuring_list is not None:
            result['QrCodeConfiguringList'] = self.qr_code_configuring_list

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group is not None:
            result['ResourceGroup'] = self.resource_group.to_map()

        if self.resource_id is not None:
            result['ResourceId'] = self.resource_id

        if self.risk_info is not None:
            result['RiskInfo'] = self.risk_info.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentImInfo') is not None:
            temp_model = main_models.ListDesktopAgentRuntimeResponseBodyDataAgentImInfo()
            self.agent_im_info = temp_model.from_map(m.get('AgentImInfo'))

        self.agent_instance_info_list = []
        if m.get('AgentInstanceInfoList') is not None:
            for k1 in m.get('AgentInstanceInfoList'):
                temp_model = main_models.ListDesktopAgentRuntimeResponseBodyDataAgentInstanceInfoList()
                self.agent_instance_info_list.append(temp_model.from_map(k1))

        if m.get('AuthUsers') is not None:
            self.auth_users = m.get('AuthUsers')

        if m.get('ChannelConfigure') is not None:
            self.channel_configure = m.get('ChannelConfigure')

        if m.get('ChannelConfiguredList') is not None:
            self.channel_configured_list = m.get('ChannelConfiguredList')

        if m.get('DesktopId') is not None:
            self.desktop_id = m.get('DesktopId')

        if m.get('DesktopName') is not None:
            self.desktop_name = m.get('DesktopName')

        if m.get('DesktopStatus') is not None:
            self.desktop_status = m.get('DesktopStatus')

        if m.get('HasAuthUser') is not None:
            self.has_auth_user = m.get('HasAuthUser')

        if m.get('ModelConfigure') is not None:
            self.model_configure = m.get('ModelConfigure')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('QrCodeConfiguringList') is not None:
            self.qr_code_configuring_list = m.get('QrCodeConfiguringList')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroup') is not None:
            temp_model = main_models.ListDesktopAgentRuntimeResponseBodyDataResourceGroup()
            self.resource_group = temp_model.from_map(m.get('ResourceGroup'))

        if m.get('ResourceId') is not None:
            self.resource_id = m.get('ResourceId')

        if m.get('RiskInfo') is not None:
            temp_model = main_models.ListDesktopAgentRuntimeResponseBodyDataRiskInfo()
            self.risk_info = temp_model.from_map(m.get('RiskInfo'))

        return self

class ListDesktopAgentRuntimeResponseBodyDataRiskInfo(DaraModel):
    def __init__(
        self,
        agent_uninstalled: bool = None,
        channel_modified: bool = None,
        model_modified: bool = None,
    ):
        self.agent_uninstalled = agent_uninstalled
        self.channel_modified = channel_modified
        self.model_modified = model_modified

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_uninstalled is not None:
            result['AgentUninstalled'] = self.agent_uninstalled

        if self.channel_modified is not None:
            result['ChannelModified'] = self.channel_modified

        if self.model_modified is not None:
            result['ModelModified'] = self.model_modified

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentUninstalled') is not None:
            self.agent_uninstalled = m.get('AgentUninstalled')

        if m.get('ChannelModified') is not None:
            self.channel_modified = m.get('ChannelModified')

        if m.get('ModelModified') is not None:
            self.model_modified = m.get('ModelModified')

        return self

class ListDesktopAgentRuntimeResponseBodyDataResourceGroup(DaraModel):
    def __init__(
        self,
        resource_group_id: str = None,
        resource_group_name: str = None,
    ):
        self.resource_group_id = resource_group_id
        self.resource_group_name = resource_group_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.resource_group_name is not None:
            result['ResourceGroupName'] = self.resource_group_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('ResourceGroupName') is not None:
            self.resource_group_name = m.get('ResourceGroupName')

        return self

class ListDesktopAgentRuntimeResponseBodyDataAgentInstanceInfoList(DaraModel):
    def __init__(
        self,
        agent_instance_status: str = None,
        agent_instance_version: str = None,
        channel_configure: bool = None,
        channel_configured_list: List[str] = None,
        deployment_source: str = None,
        model_configure: bool = None,
        model_template_id: str = None,
    ):
        self.agent_instance_status = agent_instance_status
        self.agent_instance_version = agent_instance_version
        self.channel_configure = channel_configure
        self.channel_configured_list = channel_configured_list
        self.deployment_source = deployment_source
        self.model_configure = model_configure
        self.model_template_id = model_template_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_instance_status is not None:
            result['AgentInstanceStatus'] = self.agent_instance_status

        if self.agent_instance_version is not None:
            result['AgentInstanceVersion'] = self.agent_instance_version

        if self.channel_configure is not None:
            result['ChannelConfigure'] = self.channel_configure

        if self.channel_configured_list is not None:
            result['ChannelConfiguredList'] = self.channel_configured_list

        if self.deployment_source is not None:
            result['DeploymentSource'] = self.deployment_source

        if self.model_configure is not None:
            result['ModelConfigure'] = self.model_configure

        if self.model_template_id is not None:
            result['ModelTemplateId'] = self.model_template_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentInstanceStatus') is not None:
            self.agent_instance_status = m.get('AgentInstanceStatus')

        if m.get('AgentInstanceVersion') is not None:
            self.agent_instance_version = m.get('AgentInstanceVersion')

        if m.get('ChannelConfigure') is not None:
            self.channel_configure = m.get('ChannelConfigure')

        if m.get('ChannelConfiguredList') is not None:
            self.channel_configured_list = m.get('ChannelConfiguredList')

        if m.get('DeploymentSource') is not None:
            self.deployment_source = m.get('DeploymentSource')

        if m.get('ModelConfigure') is not None:
            self.model_configure = m.get('ModelConfigure')

        if m.get('ModelTemplateId') is not None:
            self.model_template_id = m.get('ModelTemplateId')

        return self

class ListDesktopAgentRuntimeResponseBodyDataAgentImInfo(DaraModel):
    def __init__(
        self,
        agent_im_status: str = None,
        cloud_space_status: str = None,
    ):
        self.agent_im_status = agent_im_status
        self.cloud_space_status = cloud_space_status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_im_status is not None:
            result['AgentImStatus'] = self.agent_im_status

        if self.cloud_space_status is not None:
            result['CloudSpaceStatus'] = self.cloud_space_status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentImStatus') is not None:
            self.agent_im_status = m.get('AgentImStatus')

        if m.get('CloudSpaceStatus') is not None:
            self.cloud_space_status = m.get('CloudSpaceStatus')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class GetResourceRenewPriceResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.GetResourceRenewPriceResponseBodyData = None,
        request_id: str = None,
    ):
        # The price object.
        self.data = data
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            temp_model = main_models.GetResourceRenewPriceResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class GetResourceRenewPriceResponseBodyData(DaraModel):
    def __init__(
        self,
        price: main_models.GetResourceRenewPriceResponseBodyDataPrice = None,
        rules: List[main_models.GetResourceRenewPriceResponseBodyDataRules] = None,
    ):
        # The price details.
        self.price = price
        # The price calculation rules.
        self.rules = rules

    def validate(self):
        if self.price:
            self.price.validate()
        if self.rules:
            for v1 in self.rules:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.price is not None:
            result['Price'] = self.price.to_map()

        result['Rules'] = []
        if self.rules is not None:
            for k1 in self.rules:
                result['Rules'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Price') is not None:
            temp_model = main_models.GetResourceRenewPriceResponseBodyDataPrice()
            self.price = temp_model.from_map(m.get('Price'))

        self.rules = []
        if m.get('Rules') is not None:
            for k1 in m.get('Rules'):
                temp_model = main_models.GetResourceRenewPriceResponseBodyDataRules()
                self.rules.append(temp_model.from_map(k1))

        return self

class GetResourceRenewPriceResponseBodyDataRules(DaraModel):
    def __init__(
        self,
        description: str = None,
        rule_id: int = None,
    ):
        # The description of the price calculation rule.
        self.description = description
        # The ID of the price calculation rule.
        self.rule_id = rule_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.description is not None:
            result['Description'] = self.description

        if self.rule_id is not None:
            result['RuleId'] = self.rule_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('RuleId') is not None:
            self.rule_id = m.get('RuleId')

        return self

class GetResourceRenewPriceResponseBodyDataPrice(DaraModel):
    def __init__(
        self,
        currency: str = None,
        discount_price: str = None,
        original_price: str = None,
        promotions: List[main_models.GetResourceRenewPriceResponseBodyDataPricePromotions] = None,
        trade_price: str = None,
    ):
        # The currency type.
        self.currency = currency
        # The discount. The actual price is calculated based on the following formula: Actual price = Original price - Discount.
        self.discount_price = discount_price
        # The original price.
        self.original_price = original_price
        # The coupon description.
        self.promotions = promotions
        # The actual price. The actual price is calculated based on the following formula: Actual price = Original price - Discount.
        self.trade_price = trade_price

    def validate(self):
        if self.promotions:
            for v1 in self.promotions:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.currency is not None:
            result['Currency'] = self.currency

        if self.discount_price is not None:
            result['DiscountPrice'] = self.discount_price

        if self.original_price is not None:
            result['OriginalPrice'] = self.original_price

        result['Promotions'] = []
        if self.promotions is not None:
            for k1 in self.promotions:
                result['Promotions'].append(k1.to_map() if k1 else None)

        if self.trade_price is not None:
            result['TradePrice'] = self.trade_price

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Currency') is not None:
            self.currency = m.get('Currency')

        if m.get('DiscountPrice') is not None:
            self.discount_price = m.get('DiscountPrice')

        if m.get('OriginalPrice') is not None:
            self.original_price = m.get('OriginalPrice')

        self.promotions = []
        if m.get('Promotions') is not None:
            for k1 in m.get('Promotions'):
                temp_model = main_models.GetResourceRenewPriceResponseBodyDataPricePromotions()
                self.promotions.append(temp_model.from_map(k1))

        if m.get('TradePrice') is not None:
            self.trade_price = m.get('TradePrice')

        return self

class GetResourceRenewPriceResponseBodyDataPricePromotions(DaraModel):
    def __init__(
        self,
        option_code: str = None,
        promotion_desc: str = None,
        promotion_id: str = None,
        promotion_name: str = None,
        selected: bool = None,
    ):
        # The coupon code.
        self.option_code = option_code
        # The coupon description.
        self.promotion_desc = promotion_desc
        # The coupon ID.
        self.promotion_id = promotion_id
        # The coupon name.
        self.promotion_name = promotion_name
        # Indicates whether the coupon was used.
        # 
        # Valid values:
        # 
        # *   true
        # *   false
        self.selected = selected

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.option_code is not None:
            result['OptionCode'] = self.option_code

        if self.promotion_desc is not None:
            result['PromotionDesc'] = self.promotion_desc

        if self.promotion_id is not None:
            result['PromotionId'] = self.promotion_id

        if self.promotion_name is not None:
            result['PromotionName'] = self.promotion_name

        if self.selected is not None:
            result['Selected'] = self.selected

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('OptionCode') is not None:
            self.option_code = m.get('OptionCode')

        if m.get('PromotionDesc') is not None:
            self.promotion_desc = m.get('PromotionDesc')

        if m.get('PromotionId') is not None:
            self.promotion_id = m.get('PromotionId')

        if m.get('PromotionName') is not None:
            self.promotion_name = m.get('PromotionName')

        if m.get('Selected') is not None:
            self.selected = m.get('Selected')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListModelTemplatesRequest(DaraModel):
    def __init__(
        self,
        agent_platform: str = None,
        agent_provider: str = None,
        biz_type: int = None,
        has_model: bool = None,
        model_template_id_list: List[str] = None,
        page_number: int = None,
        page_size: int = None,
    ):
        self.agent_platform = agent_platform
        # This parameter is required.
        self.agent_provider = agent_provider
        # This parameter is required.
        self.biz_type = biz_type
        self.has_model = has_model
        self.model_template_id_list = model_template_id_list
        self.page_number = page_number
        self.page_size = page_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_platform is not None:
            result['AgentPlatform'] = self.agent_platform

        if self.agent_provider is not None:
            result['AgentProvider'] = self.agent_provider

        if self.biz_type is not None:
            result['BizType'] = self.biz_type

        if self.has_model is not None:
            result['HasModel'] = self.has_model

        if self.model_template_id_list is not None:
            result['ModelTemplateIdList'] = self.model_template_id_list

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AgentPlatform') is not None:
            self.agent_platform = m.get('AgentPlatform')

        if m.get('AgentProvider') is not None:
            self.agent_provider = m.get('AgentProvider')

        if m.get('BizType') is not None:
            self.biz_type = m.get('BizType')

        if m.get('HasModel') is not None:
            self.has_model = m.get('HasModel')

        if m.get('ModelTemplateIdList') is not None:
            self.model_template_id_list = m.get('ModelTemplateIdList')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListOtaTaskResponseBody(DaraModel):
    def __init__(
        self,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        task_list: List[main_models.ListOtaTaskResponseBodyTaskList] = None,
        total_count: int = None,
    ):
        # The page number of the returned page.
        self.page_number = page_number
        # The number of entries on each page.
        self.page_size = page_size
        # The request ID.
        self.request_id = request_id
        # The OTA update tasks.
        self.task_list = task_list
        # The total number of OTA update tasks.
        self.total_count = total_count

    def validate(self):
        if self.task_list:
            for v1 in self.task_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        result['TaskList'] = []
        if self.task_list is not None:
            for k1 in self.task_list:
                result['TaskList'].append(k1.to_map() if k1 else None)

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        self.task_list = []
        if m.get('TaskList') is not None:
            for k1 in m.get('TaskList'):
                temp_model = main_models.ListOtaTaskResponseBodyTaskList()
                self.task_list.append(temp_model.from_map(k1))

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListOtaTaskResponseBodyTaskList(DaraModel):
    def __init__(
        self,
        ota_version: str = None,
        task_display_status: str = None,
        task_id: str = None,
        task_start_time: str = None,
    ):
        # The OTA version.
        self.ota_version = ota_version
        # The task status.
        # 
        # Valid values:
        # 
        # *   FAILED
        # *   RUNNING
        # *   TERMINATED
        # *   PART_FINISHED
        # *   STANDBY
        # *   FINISHED
        self.task_display_status = task_display_status
        # The task ID.
        self.task_id = task_id
        # The start time of the OTA update task. The time follows the ISO 8601 standard.
        # 
        # Use the UTC time format: yyyy-MM-ddTHH:mmZ
        self.task_start_time = task_start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ota_version is not None:
            result['OtaVersion'] = self.ota_version

        if self.task_display_status is not None:
            result['TaskDisplayStatus'] = self.task_display_status

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_start_time is not None:
            result['TaskStartTime'] = self.task_start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('OtaVersion') is not None:
            self.ota_version = m.get('OtaVersion')

        if m.get('TaskDisplayStatus') is not None:
            self.task_display_status = m.get('TaskDisplayStatus')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskStartTime') is not None:
            self.task_start_time = m.get('TaskStartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class RemoveResourceGroupModelTemplateRequest(DaraModel):
    def __init__(
        self,
        model_template_id: str = None,
        resource_group_ids: List[str] = None,
    ):
        # This parameter is required.
        self.model_template_id = model_template_id
        # This parameter is required.
        self.resource_group_ids = resource_group_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.model_template_id is not None:
            result['ModelTemplateId'] = self.model_template_id

        if self.resource_group_ids is not None:
            result['ResourceGroupIds'] = self.resource_group_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ModelTemplateId') is not None:
            self.model_template_id = m.get('ModelTemplateId')

        if m.get('ResourceGroupIds') is not None:
            self.resource_group_ids = m.get('ResourceGroupIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class DeliverToUserSlsRequest(DaraModel):
    def __init__(
        self,
        delivery_scopes: List[main_models.DeliverToUserSlsRequestDeliveryScopes] = None,
        existed_project_name: str = None,
        log_store_name: str = None,
        project_name: str = None,
        sls_region_id: str = None,
        ttl: int = None,
    ):
        # This parameter is required.
        self.delivery_scopes = delivery_scopes
        self.existed_project_name = existed_project_name
        self.log_store_name = log_store_name
        self.project_name = project_name
        # This parameter is required.
        self.sls_region_id = sls_region_id
        self.ttl = ttl

    def validate(self):
        if self.delivery_scopes:
            for v1 in self.delivery_scopes:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['DeliveryScopes'] = []
        if self.delivery_scopes is not None:
            for k1 in self.delivery_scopes:
                result['DeliveryScopes'].append(k1.to_map() if k1 else None)

        if self.existed_project_name is not None:
            result['ExistedProjectName'] = self.existed_project_name

        if self.log_store_name is not None:
            result['LogStoreName'] = self.log_store_name

        if self.project_name is not None:
            result['ProjectName'] = self.project_name

        if self.sls_region_id is not None:
            result['SlsRegionId'] = self.sls_region_id

        if self.ttl is not None:
            result['Ttl'] = self.ttl

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.delivery_scopes = []
        if m.get('DeliveryScopes') is not None:
            for k1 in m.get('DeliveryScopes'):
                temp_model = main_models.DeliverToUserSlsRequestDeliveryScopes()
                self.delivery_scopes.append(temp_model.from_map(k1))

        if m.get('ExistedProjectName') is not None:
            self.existed_project_name = m.get('ExistedProjectName')

        if m.get('LogStoreName') is not None:
            self.log_store_name = m.get('LogStoreName')

        if m.get('ProjectName') is not None:
            self.project_name = m.get('ProjectName')

        if m.get('SlsRegionId') is not None:
            self.sls_region_id = m.get('SlsRegionId')

        if m.get('Ttl') is not None:
            self.ttl = m.get('Ttl')

        return self

class DeliverToUserSlsRequestDeliveryScopes(DaraModel):
    def __init__(
        self,
        product_type: str = None,
    ):
        # This parameter is required.
        self.product_type = product_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.product_type is not None:
            result['ProductType'] = self.product_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        return self

